@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Record;
 # ABSTRACT: Container for Cypher result values
-$Neo4j::Driver::Record::VERSION = '0.19'; # TRIAL
+$Neo4j::Driver::Record::VERSION = '0.24'; # TRIAL
 
 use Carp qw(croak);
 use JSON::MaybeXS 1.003003 qw(is_bool);
@@ -110,7 +110,7 @@ Neo4j::Driver::Record - Container for Cypher result values
 
 =head1 VERSION
 
-version 0.19
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -163,9 +163,9 @@ types as shown in the following table.
  Boolean         JSON::PP::true or JSON::PP::false
  null            undef
  
- Node            Neo4j::Driver::Type::Node
- Relationship    Neo4j::Driver::Type::Relationship
- Path            Neo4j::Driver::Type::Path
+ Node            Neo4j::Types::Node
+ Relationship    Neo4j::Types::Relationship
+ Path            Neo4j::Types::Path
  
  List            array reference
  Map             hash reference
@@ -173,14 +173,24 @@ types as shown in the following table.
 Boolean values are returned as JSON types; use C<!!> to force-convert
 to a plain Perl boolean value if necessary.
 
-Note that early versions of this class returned nodes, relationships
-and paths as hashrefs or arrayrefs rather than blessed objects. This
-was a bug. The underlying data structure of nodes and relationships
-is an implementation detail that should not be relied upon. If you
-try to treat L<Neo4j::Driver::Type::Node>,
-L<Neo4j::Driver::Type::Relationship> or L<Neo4j::Driver::Type::Path>
-objects as hashrefs or arrayrefs, your code will eventually fail
-with a future version of this driver.
+Neo4j types are currently implemented by the following packages:
+
+=over
+
+=item * L<Neo4j::Types::Node> is implemented by
+L<Neo4j::Driver::Type::Node>.
+
+=item * L<Neo4j::Types::Relationship> is implemented by
+L<Neo4j::Driver::Type::Relationship>.
+
+=item * L<Neo4j::Types::Path> is implemented by
+L<Neo4j::Driver::Type::Path>.
+
+=back
+
+In a future version of this driver, values retrieved over a Bolt
+connection will be implemented by other packages, but they will
+continue to inherit from L<Neo4j::Types> and have that interface.
 
 =head2 data
 
@@ -204,6 +214,7 @@ these features.
 Allows accessing the graph response the Neo4j server can deliver via
 HTTP. Requires the C<return_graph> field to be set on the
 L<Transaction|Neo4j::Driver::Transaction>
+and Jolt to be disabled (which is not recommended)
 before the statement is executed.
 
 =head1 SEE ALSO
