@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Result::JSON;
 # ABSTRACT: JSON/REST result handler
-$Neo4j::Driver::Result::JSON::VERSION = '0.19'; # TRIAL
+$Neo4j::Driver::Result::JSON::VERSION = '0.24'; # TRIAL
 
 use parent 'Neo4j::Driver::Result';
 
@@ -17,8 +17,9 @@ use JSON::MaybeXS 1.003003 ();
 use URI 1.31;
 
 
-our $MEDIA_TYPE = "application/json";
-our $ACCEPT_HEADER = "$MEDIA_TYPE";
+my $MEDIA_TYPE = "application/json";
+my $ACCEPT_HEADER = "$MEDIA_TYPE";
+my $ACCEPT_HEADER_POST = "$MEDIA_TYPE;q=0.5";
 
 
 sub new {
@@ -78,7 +79,8 @@ sub _parse_json {
 	
 	my @errors = ();
 	if (! $params->{http_header}->{success}) {
-		push @errors, "HTTP error: $params->{http_header}->{status} $params->{http_header}->{reason} on $params->{http_method} to $params->{http_path}";
+		my $reason_phrase = $params->{http_agent}->http_reason;
+		push @errors, "HTTP error: $params->{http_header}->{status} $reason_phrase on $params->{http_method} to $params->{http_path}";
 	}
 	
 	my $json;
@@ -233,9 +235,12 @@ sub _deep_bless {
 # Return a list of the media types this module can handle, fit for
 # use in an HTTP Accept header field.
 sub _accept_header {
-	my (undef, $want_jolt, $http_method) = @_;
+	my (undef, $want_jolt, $method) = @_;
 	
+	# Note: Neo4j < 4.2 doesn't fail gracefully if Jolt is the only acceptable response type.
 	return if $want_jolt;
+	
+	return ($ACCEPT_HEADER_POST) if $method eq 'POST';
 	return ($ACCEPT_HEADER);
 }
 
@@ -262,13 +267,23 @@ Neo4j::Driver::Result::JSON - JSON/REST result handler
 
 =head1 VERSION
 
-version 0.19
+version 0.24
 
 =head1 DESCRIPTION
 
 The L<Neo4j::Driver::Result::JSON> package is not part of the
 public L<Neo4j::Driver> API.
 
+=head1 SEE ALSO
+
+=over
+
+=item * L<Neo4j::Driver::Net>
+
+=item * L<Neo4j::Driver::Result>
+
+=back
+
 =head1 AUTHOR
 
 Arne Johannessen <ajnn@cpan.org>
