@@ -5,7 +5,10 @@ use utf8;
 
 package Neo4j::Driver::ResultColumns;
 # ABSTRACT: Structure definition of Cypher result values
-$Neo4j::Driver::ResultColumns::VERSION = '0.19'; # TRIAL
+$Neo4j::Driver::ResultColumns::VERSION = '0.24'; # TRIAL
+
+# This package is not part of the public Neo4j::Driver API.
+
 
 use Carp qw(croak);
 
@@ -59,36 +62,3 @@ sub count {
 
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Neo4j::Driver::ResultColumns - Structure definition of Cypher result values
-
-=head1 VERSION
-
-version 0.19
-
-=head1 DESCRIPTION
-
-The L<Neo4j::Driver::ResultColumns> package is not part of the
-public L<Neo4j::Driver> API.
-
-=head1 AUTHOR
-
-Arne Johannessen <ajnn@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2016-2021 by Arne Johannessen.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=cut
