@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Transaction;
 # ABSTRACT: Logical container for an atomic unit of work
-$Neo4j::Driver::Transaction::VERSION = '0.19'; # TRIAL
+$Neo4j::Driver::Transaction::VERSION = '0.24'; # TRIAL
 
 use Carp qw(croak);
 our @CARP_NOT = qw(
@@ -65,10 +65,10 @@ sub run {
 sub _prepare {
 	my ($self, $query, @parameters) = @_;
 	
-	croak 'Query cannot be unblessed reference' if ref $query && ! blessed $query;
-	if ($query->isa('REST::Neo4p::Query')) {
+	if (ref $query) {
+		croak 'Query cannot be unblessed reference' unless blessed $query;
 		# REST::Neo4p::Query->query is not part of the documented API
-		$query = '' . $query->query;
+		$query = '' . $query->query if $query->isa('REST::Neo4p::Query');
 	}
 	
 	my $params;
@@ -266,7 +266,7 @@ Neo4j::Driver::Transaction - Logical container for an atomic unit of work
 
 =head1 VERSION
 
-version 0.19
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -319,12 +319,11 @@ After committing the transaction is closed and can no longer be used.
  $bool = $transaction->is_open;
 
 Report whether this transaction is still open, which means commit
-or rollback did not happen.
+or rollback has not happened and the transaction has not timed out.
 
-On HTTP connections, a transaction can timeout on the server due
-to inactivity. In this case, it may in fact be closed even though
-this method returns a truthy value. The Neo4j server default
-C<dbms.rest.transaction.idle_timeout> is 60 seconds.
+Bolt transactions by default have no timeout, while the default
+C<dbms.rest.transaction.idle_timeout> for HTTP transactions is
+S<60 seconds.>
 
 =head2 rollback
 
@@ -401,6 +400,12 @@ converted to strings before they are sent to the Neo4j server.
 This driver always reports all errors using C<die()>. Error messages
 received from the Neo4j server are passed on as-is.
 
+Statement errors occur when the statement is executed on the server.
+This may not necessarily have happened by the time C<run()> returns.
+If you use C<try> to handle errors, make sure you use the
+L<Result|Neo4j::Driver::Result> within the C<try> block, for example
+by calling one of the methods C<fetch()>, C<list()> or C<summary()>.
+
 Transactions are rolled back and closed automatically if the Neo4j
 server encounters an error when running a query. However, if an
 I<internal> error occurs in the driver or in one of its supporting
@@ -471,6 +476,7 @@ The ability to disable the statistics may be removed in future.
 
 =head2 Return results in graph format
 
+ $session = $driver->config( jolt => 0 )->session;
  $transaction = $session->begin_transaction;
  $transaction->{return_graph} = 1;
  $records = $transaction->run('...')->list;
@@ -480,8 +486,11 @@ The ability to disable the statistics may be removed in future.
  }
 
 The Neo4j HTTP JSON API supports a "graph" results data format.
-This driver exposes this feature to the client and will continue
-to do so, but the interface is not yet finalised.
+This feature is only available when Jolt is disabled, which is
+not recommended. The C<return_graph> option will most likely be
+removed entirely in future versions, as requesting the "graph"
+result is also possible by using a custom networking module;
+see L<Neo4j::Driver::Net>.
 
 =head1 SEE ALSO
 
